==> devops-client-java-1.0.4-sources.jar: io/alauda/devops/java/client/models/V1alpha1ToolTypeSpecFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.alauda.devops.java.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.alauda.devops.java.client.fluent.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;

public interface V1alpha1ToolTypeSpecFluent<A extends V1alpha1ToolTypeSpecFluent<A>> extends Fluent<A>{


    public String getApiPath();
    public A withApiPath(String apiPath);
    public Boolean hasApiPath();
    public A withNewApiPath(String arg1);
    public A withNewApiPath(StringBuilder arg1);
    public A withNewApiPath(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildDisplayName instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1ToolTypeSpecDisplayName getDisplayName();
    public V1alpha1ToolTypeSpecDisplayName buildDisplayName();
    public A withDisplayName(V1alpha1ToolTypeSpecDisplayName displayName);
    public Boolean hasDisplayName();
    public V1alpha1ToolTypeSpecFluent.DisplayNameNested<A> withNewDisplayName();
    public V1alpha1ToolTypeSpecFluent.DisplayNameNested<A> withNewDisplayNameLike(V1alpha1ToolTypeSpecDisplayName item);
    public V1alpha1ToolTypeSpecFluent.DisplayNameNested<A> editDisplayName();
    public V1alpha1ToolTypeSpecFluent.DisplayNameNested<A> editOrNewDisplayName();
    public V1alpha1ToolTypeSpecFluent.DisplayNameNested<A> editOrNewDisplayNameLike(V1alpha1ToolTypeSpecDisplayName item);
    public Boolean isEnabled();
    public A withEnabled(Boolean enabled);
    public Boolean hasEnabled();
    public A withNewEnabled(String arg1);
    public A withNewEnabled(boolean arg1);
    public Boolean isEnterprise();
    public A withEnterprise(Boolean enterprise);
    public Boolean hasEnterprise();
    public A withNewEnterprise(String arg1);
    public A withNewEnterprise(boolean arg1);
    public String getHost();
    public A withHost(String host);
    public Boolean hasHost();
    public A withNewHost(String arg1);
    public A withNewHost(StringBuilder arg1);
    public A withNewHost(StringBuffer arg1);
    public String getHtml();
    public A withHtml(String html);
    public Boolean hasHtml();
    public A withNewHtml(String arg1);
    public A withNewHtml(StringBuilder arg1);
    public A withNewHtml(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public Boolean isPublic();
    public A withPublic(Boolean _public);
    public Boolean hasPublic();
    public A withNewPublic(String arg1);
    public A withNewPublic(boolean arg1);
    public Boolean isRoleSyncEnabled();
    public A withRoleSyncEnabled(Boolean roleSyncEnabled);
    public Boolean hasRoleSyncEnabled();
    public A withNewRoleSyncEnabled(String arg1);
    public A withNewRoleSyncEnabled(boolean arg1);
    public A addToSupportedSecretTypes(int index,V1alpha1ToolTypeSpecSupportedSecretTypes item);
    public A setToSupportedSecretTypes(int index,V1alpha1ToolTypeSpecSupportedSecretTypes item);
    public A addToSupportedSecretTypes(V1alpha1ToolTypeSpecSupportedSecretTypes... items);
    public A addAllToSupportedSecretTypes(Collection<V1alpha1ToolTypeSpecSupportedSecretTypes> items);
    public A removeFromSupportedSecretTypes(V1alpha1ToolTypeSpecSupportedSecretTypes... items);
    public A removeAllFromSupportedSecretTypes(Collection<V1alpha1ToolTypeSpecSupportedSecretTypes> items);
    
/**
 * This method has been deprecated, please use method buildSupportedSecretTypes instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1ToolTypeSpecSupportedSecretTypes> getSupportedSecretTypes();
    public List<V1alpha1ToolTypeSpecSupportedSecretTypes> buildSupportedSecretTypes();
    public V1alpha1ToolTypeSpecSupportedSecretTypes buildSupportedSecretType(int index);
    public V1alpha1ToolTypeSpecSupportedSecretTypes buildFirstSupportedSecretType();
    public V1alpha1ToolTypeSpecSupportedSecretTypes buildLastSupportedSecretType();
    public V1alpha1ToolTypeSpecSupportedSecretTypes buildMatchingSupportedSecretType(io.alauda.devops.java.client.fluent.Predicate<V1alpha1ToolTypeSpecSupportedSecretTypesBuilder> predicate);
    public Boolean hasMatchingSupportedSecretType(io.alauda.devops.java.client.fluent.Predicate<V1alpha1ToolTypeSpecSupportedSecretTypesBuilder> predicate);
    public A withSupportedSecretTypes(List<V1alpha1ToolTypeSpecSupportedSecretTypes> supportedSecretTypes);
    public A withSupportedSecretTypes(V1alpha1ToolTypeSpecSupportedSecretTypes... supportedSecretTypes);
    public Boolean hasSupportedSecretTypes();
    public V1alpha1ToolTypeSpecFluent.SupportedSecretTypesNested<A> addNewSupportedSecretType();
    public V1alpha1ToolTypeSpecFluent.SupportedSecretTypesNested<A> addNewSupportedSecretTypeLike(V1alpha1ToolTypeSpecSupportedSecretTypes item);
    public V1alpha1ToolTypeSpecFluent.SupportedSecretTypesNested<A> setNewSupportedSecretTypeLike(int index,V1alpha1ToolTypeSpecSupportedSecretTypes item);
    public V1alpha1ToolTypeSpecFluent.SupportedSecretTypesNested<A> editSupportedSecretType(int index);
    public V1alpha1ToolTypeSpecFluent.SupportedSecretTypesNested<A> editFirstSupportedSecretType();
    public V1alpha1ToolTypeSpecFluent.SupportedSecretTypesNested<A> editLastSupportedSecretType();
    public V1alpha1ToolTypeSpecFluent.SupportedSecretTypesNested<A> editMatchingSupportedSecretType(io.alauda.devops.java.client.fluent.Predicate<V1alpha1ToolTypeSpecSupportedSecretTypesBuilder> predicate);
    public A addToToolCategory(int index,V1alpha1ToolCategoryRef item);
    public A setToToolCategory(int index,V1alpha1ToolCategoryRef item);
    public A addToToolCategory(V1alpha1ToolCategoryRef... items);
    public A addAllToToolCategory(Collection<V1alpha1ToolCategoryRef> items);
    public A removeFromToolCategory(V1alpha1ToolCategoryRef... items);
    public A removeAllFromToolCategory(Collection<V1alpha1ToolCategoryRef> items);
    
/**
 * This method has been deprecated, please use method buildToolCategory instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1ToolCategoryRef> getToolCategory();
    public List<V1alpha1ToolCategoryRef> buildToolCategory();
    public V1alpha1ToolCategoryRef buildToolCategory(int index);
    public V1alpha1ToolCategoryRef buildFirstToolCategory();
    public V1alpha1ToolCategoryRef buildLastToolCategory();
    public V1alpha1ToolCategoryRef buildMatchingToolCategory(io.alauda.devops.java.client.fluent.Predicate<V1alpha1ToolCategoryRefBuilder> predicate);
    public Boolean hasMatchingToolCategory(io.alauda.devops.java.client.fluent.Predicate<V1alpha1ToolCategoryRefBuilder> predicate);
    public A withToolCategory(List<V1alpha1ToolCategoryRef> toolCategory);
    public A withToolCategory(V1alpha1ToolCategoryRef... toolCategory);
    public Boolean hasToolCategory();
    public V1alpha1ToolTypeSpecFluent.ToolCategoryNested<A> addNewToolCategory();
    public V1alpha1ToolTypeSpecFluent.ToolCategoryNested<A> addNewToolCategoryLike(V1alpha1ToolCategoryRef item);
    public V1alpha1ToolTypeSpecFluent.ToolCategoryNested<A> setNewToolCategoryLike(int index,V1alpha1ToolCategoryRef item);
    public V1alpha1ToolTypeSpecFluent.ToolCategoryNested<A> editToolCategory(int index);
    public V1alpha1ToolTypeSpecFluent.ToolCategoryNested<A> editFirstToolCategory();
    public V1alpha1ToolTypeSpecFluent.ToolCategoryNested<A> editLastToolCategory();
    public V1alpha1ToolTypeSpecFluent.ToolCategoryNested<A> editMatchingToolCategory(io.alauda.devops.java.client.fluent.Predicate<V1alpha1ToolCategoryRefBuilder> predicate);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface DisplayNameNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1ToolTypeSpecDisplayNameFluent<V1alpha1ToolTypeSpecFluent.DisplayNameNested<N>>{

        
    public N and();    public N endDisplayName();
}
    public interface SupportedSecretTypesNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1ToolTypeSpecSupportedSecretTypesFluent<V1alpha1ToolTypeSpecFluent.SupportedSecretTypesNested<N>>{

        
    public N and();    public N endSupportedSecretType();
}
    public interface ToolCategoryNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1ToolCategoryRefFluent<V1alpha1ToolTypeSpecFluent.ToolCategoryNested<N>>{

        
    public N and();    public N endToolCategory();
}


}

==> devops-client-java-1.0.6-sources.jar: io/alauda/devops/java/client/models/V1alpha1ToolTypeSpecFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.alauda.devops.java.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.alauda.devops.java.client.fluent.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;

public interface V1alpha1ToolTypeSpecFluent<A extends V1alpha1ToolTypeSpecFluent<A>> extends Fluent<A>{


    public String getApiPath();
    public A withApiPath(String apiPath);
    public Boolean hasApiPath();
    public A withNewApiPath(String arg1);
    public A withNewApiPath(StringBuilder arg1);
    public A withNewApiPath(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildDescription instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1ToolTypeSpecDisplayName getDescription();
    public V1alpha1ToolTypeSpecDisplayName buildDescription();
    public A withDescription(V1alpha1ToolTypeSpecDisplayName description);
    public Boolean hasDescription();
    public V1alpha1ToolTypeSpecFluent.DescriptionNested<A> withNewDescription();
    public V1alpha1ToolTypeSpecFluent.DescriptionNested<A> withNewDescriptionLike(V1alpha1ToolTypeSpecDisplayName item);
    public V1alpha1ToolTypeSpecFluent.DescriptionNested<A> editDescription();
    public V1alpha1ToolTypeSpecFluent.DescriptionNested<A> editOrNewDescription();
    public V1alpha1ToolTypeSpecFluent.DescriptionNested<A> editOrNewDescriptionLike(V1alpha1ToolTypeSpecDisplayName item);
    
/**
 * This method has been deprecated, please use method buildDisplayName instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1ToolTypeSpecDisplayName getDisplayName();
    public V1alpha1ToolTypeSpecDisplayName buildDisplayName();
    public A withDisplayName(V1alpha1ToolTypeSpecDisplayName displayName);
    public Boolean hasDisplayName();
    public V1alpha1ToolTypeSpecFluent.DisplayNameNested<A> withNewDisplayName();
    public V1alpha1ToolTypeSpecFluent.DisplayNameNested<A> withNewDisplayNameLike(V1alpha1ToolTypeSpecDisplayName item);
    public V1alpha1ToolTypeSpecFluent.DisplayNameNested<A> editDisplayName();
    public V1alpha1ToolTypeSpecFluent.DisplayNameNested<A> editOrNewDisplayName();
    public V1alpha1ToolTypeSpecFluent.DisplayNameNested<A> editOrNewDisplayNameLike(V1alpha1ToolTypeSpecDisplayName item);
    public Boolean isEnabled();
    public A withEnabled(Boolean enabled);
    public Boolean hasEnabled();
    public A withNewEnabled(String arg1);
    public A withNewEnabled(boolean arg1);
    public Boolean isEnterprise();
    public A withEnterprise(Boolean enterprise);
    public Boolean hasEnterprise();
    public A withNewEnterprise(String arg1);
    public A withNewEnterprise(boolean arg1);
    public String getHost();
    public A withHost(String host);
    public Boolean hasHost();
    public A withNewHost(String arg1);
    public A withNewHost(StringBuilder arg1);
    public A withNewHost(StringBuffer arg1);
    public String getHtml();
    public A withHtml(String html);
    public Boolean hasHtml();
    public A withNewHtml(String arg1);
    public A withNewHtml(StringBuilder arg1);
    public A withNewHtml(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public Boolean isPublic();
    public A withPublic(Boolean _public);
    public Boolean hasPublic();
    public A withNewPublic(String arg1);
    public A withNewPublic(boolean arg1);
    public String getRecommendedVersion();
    public A withRecommendedVersion(String recommendedVersion);
    public Boolean hasRecommendedVersion();
    public A withNewRecommendedVersion(String arg1);
    public A withNewRecommendedVersion(StringBuilder arg1);
    public A withNewRecommendedVersion(StringBuffer arg1);
    public Boolean isRoleSyncEnabled();
    public A withRoleSyncEnabled(Boolean roleSyncEnabled);
    public Boolean hasRoleSyncEnabled();
    public A withNewRoleSyncEnabled(String arg1);
    public A withNewRoleSyncEnabled(boolean arg1);
    public A addToSupportedSecretTypes(int index,V1alpha1ToolTypeSpecSupportedSecretTypes item);
    public A setToSupportedSecretTypes(int index,V1alpha1ToolTypeSpecSupportedSecretTypes item);
    public A addToSupportedSecretTypes(V1alpha1ToolTypeSpecSupportedSecretTypes... items);
    public A addAllToSupportedSecretTypes(Collection<V1alpha1ToolTypeSpecSupportedSecretTypes> items);
    public A removeFromSupportedSecretTypes(V1alpha1ToolTypeSpecSupportedSecretTypes... items);
    public A removeAllFromSupportedSecretTypes(Collection<V1alpha1ToolTypeSpecSupportedSecretTypes> items);
    
/**
 * This method has been deprecated, please use method buildSupportedSecretTypes instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1ToolTypeSpecSupportedSecretTypes> getSupportedSecretTypes();
    public List<V1alpha1ToolTypeSpecSupportedSecretTypes> buildSupportedSecretTypes();
    public V1alpha1ToolTypeSpecSupportedSecretTypes buildSupportedSecretType(int index);
    public V1alpha1ToolTypeSpecSupportedSecretTypes buildFirstSupportedSecretType();
    public V1alpha1ToolTypeSpecSupportedSecretTypes buildLastSupportedSecretType();
    public V1alpha1ToolTypeSpecSupportedSecretTypes buildMatchingSupportedSecretType(io.alauda.devops.java.client.fluent.Predicate<V1alpha1ToolTypeSpecSupportedSecretTypesBuilder> predicate);
    public Boolean hasMatchingSupportedSecretType(io.alauda.devops.java.client.fluent.Predicate<V1alpha1ToolTypeSpecSupportedSecretTypesBuilder> predicate);
    public A withSupportedSecretTypes(List<V1alpha1ToolTypeSpecSupportedSecretTypes> supportedSecretTypes);
    public A withSupportedSecretTypes(V1alpha1ToolTypeSpecSupportedSecretTypes... supportedSecretTypes);
    public Boolean hasSupportedSecretTypes();
    public V1alpha1ToolTypeSpecFluent.SupportedSecretTypesNested<A> addNewSupportedSecretType();
    public V1alpha1ToolTypeSpecFluent.SupportedSecretTypesNested<A> addNewSupportedSecretTypeLike(V1alpha1ToolTypeSpecSupportedSecretTypes item);
    public V1alpha1ToolTypeSpecFluent.SupportedSecretTypesNested<A> setNewSupportedSecretTypeLike(int index,V1alpha1ToolTypeSpecSupportedSecretTypes item);
    public V1alpha1ToolTypeSpecFluent.SupportedSecretTypesNested<A> editSupportedSecretType(int index);
    public V1alpha1ToolTypeSpecFluent.SupportedSecretTypesNested<A> editFirstSupportedSecretType();
    public V1alpha1ToolTypeSpecFluent.SupportedSecretTypesNested<A> editLastSupportedSecretType();
    public V1alpha1ToolTypeSpecFluent.SupportedSecretTypesNested<A> editMatchingSupportedSecretType(io.alauda.devops.java.client.fluent.Predicate<V1alpha1ToolTypeSpecSupportedSecretTypesBuilder> predicate);
    public A addToToolCategory(int index,V1alpha1ToolCategoryRef item);
    public A setToToolCategory(int index,V1alpha1ToolCategoryRef item);
    public A addToToolCategory(V1alpha1ToolCategoryRef... items);
    public A addAllToToolCategory(Collection<V1alpha1ToolCategoryRef> items);
    public A removeFromToolCategory(V1alpha1ToolCategoryRef... items);
    public A removeAllFromToolCategory(Collection<V1alpha1ToolCategoryRef> items);
    
/**
 * This method has been deprecated, please use method buildToolCategory instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1ToolCategoryRef> getToolCategory();
    public List<V1alpha1ToolCategoryRef> buildToolCategory();
    public V1alpha1ToolCategoryRef buildToolCategory(int index);
    public V1alpha1ToolCategoryRef buildFirstToolCategory();
    public V1alpha1ToolCategoryRef buildLastToolCategory();
    public V1alpha1ToolCategoryRef buildMatchingToolCategory(io.alauda.devops.java.client.fluent.Predicate<V1alpha1ToolCategoryRefBuilder> predicate);
    public Boolean hasMatchingToolCategory(io.alauda.devops.java.client.fluent.Predicate<V1alpha1ToolCategoryRefBuilder> predicate);
    public A withToolCategory(List<V1alpha1ToolCategoryRef> toolCategory);
    public A withToolCategory(V1alpha1ToolCategoryRef... toolCategory);
    public Boolean hasToolCategory();
    public V1alpha1ToolTypeSpecFluent.ToolCategoryNested<A> addNewToolCategory();
    public V1alpha1ToolTypeSpecFluent.ToolCategoryNested<A> addNewToolCategoryLike(V1alpha1ToolCategoryRef item);
    public V1alpha1ToolTypeSpecFluent.ToolCategoryNested<A> setNewToolCategoryLike(int index,V1alpha1ToolCategoryRef item);
    public V1alpha1ToolTypeSpecFluent.ToolCategoryNested<A> editToolCategory(int index);
    public V1alpha1ToolTypeSpecFluent.ToolCategoryNested<A> editFirstToolCategory();
    public V1alpha1ToolTypeSpecFluent.ToolCategoryNested<A> editLastToolCategory();
    public V1alpha1ToolTypeSpecFluent.ToolCategoryNested<A> editMatchingToolCategory(io.alauda.devops.java.client.fluent.Predicate<V1alpha1ToolCategoryRefBuilder> predicate);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface DescriptionNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1ToolTypeSpecDisplayNameFluent<V1alpha1ToolTypeSpecFluent.DescriptionNested<N>>{

        
    public N and();    public N endDescription();
}
    public interface DisplayNameNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1ToolTypeSpecDisplayNameFluent<V1alpha1ToolTypeSpecFluent.DisplayNameNested<N>>{

        
    public N and();    public N endDisplayName();
}
    public interface SupportedSecretTypesNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1ToolTypeSpecSupportedSecretTypesFluent<V1alpha1ToolTypeSpecFluent.SupportedSecretTypesNested<N>>{

        
    public N and();    public N endSupportedSecretType();
}
    public interface ToolCategoryNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1ToolCategoryRefFluent<V1alpha1ToolTypeSpecFluent.ToolCategoryNested<N>>{

        
    public N and();    public N endToolCategory();
}


}
